This nodes package provides nodes for linear algebra operations on matrices using numpy.
It implements only a small subset of the numpy functions, but it should be easy to add more.
This is a good example of how to implement a nodes package for a specific library.
Ryven comes with a little example project showcasing this package.